Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6706)

Unified Diff: content/browser/renderer_host/media/video_capture_manager.h

Issue 2810723002: Refactor VideoCaptureManager::GetDeviceFormatsInUse() (Closed)
Patch Set: Addressed review comments Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/media/video_capture_manager.h
diff --git a/content/browser/renderer_host/media/video_capture_manager.h b/content/browser/renderer_host/media/video_capture_manager.h
index 0021c1e4036b7325d04d0ced58d68e40f5257612..f40f6fb86921e10509c953b92616941aeb8cd54f 100644
--- a/content/browser/renderer_host/media/video_capture_manager.h
+++ b/content/browser/renderer_host/media/video_capture_manager.h
@@ -149,13 +149,12 @@ class CONTENT_EXPORT VideoCaptureManager
// otherwise. |formats_in_use| is empty if the device is not in use.
bool GetDeviceFormatsInUse(media::VideoCaptureSessionId capture_session_id,
media::VideoCaptureFormats* formats_in_use);
- // Retrieves the format(s) currently in use. Returns false if the
- // |stream_type|, |device_id| pair is not found. Returns true and
- // |formats_in_use| otherwise. |formats_in_use| is empty if the device is not
- // in use.
- bool GetDeviceFormatsInUse(MediaStreamType stream_type,
- const std::string& device_id,
- media::VideoCaptureFormats* supported_formats);
+ // Retrieves the format currently in use. Returns base::nullopt if the
+ // |stream_type|, |device_id| pair is not found. Returns in-use format of the
+ // device otherwise.
+ base::Optional<media::VideoCaptureFormat> GetDeviceFormatInUse(
+ MediaStreamType stream_type,
+ const std::string& device_id);
// Sets the platform-dependent window ID for the desktop capture notification
// UI for the given session.

Powered by Google App Engine
This is Rietveld 408576698